Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

16x11 - Driving Miss Unconventional

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

16x11 - Driving Miss Unconventional

Post by bunniefuu »

HEIDI:
Previously on Project Runway...

-Claire.
-Yes?

Is it true that you have had

a measuring tape in your room?

I have a measuring tape.

Is it true that you've been

measuring garments in your room?

I have measured a tank top
and crotch of a pair of pants.

All right. We must rescind
your win and send you home.

Claire's possession
of the measuring tape

in her hotel room
and the fact that she used it

is what is against
the rules here.

Your challenge is to create

-an avant-garde look.
-KENYA: ♪ Make it work. ♪

MARGARITA:
Since the twins left,

this is like
a whole new place to work in.

This challenge is difficult
for you, isn't it?

-Yeah, it is.
-MICHAEL: I can tell

that Brandon's running out
of ideas.

♪ ♪

I definitely want to go dancing
in that look.

-It looks so well made.
-Michael, congratulations.

You are the winner
of this challenge.

It really looks so unfinished.

Batani, I'm sorry. You're out.

I don't feel
that it's that risky.

Amy, I'm sorry.
You're out as well.

Oh.

♪ ♪

♪ ♪

[bicycle bell dings]

Congrats on the win, Mike.

-KENTARO: I'm so proud of you.
-Thank you.

So it's the top six,

and there's no more safe zone.

No immunity.
I mean, the stakes are high.

I did not expect them to say...

-Double whammy.
-"Amy, you're gone, too."

Anything can happen
at this point.

♪ ♪

[laughter]

-Hello, designers.
-DESIGNERS: Hello.

This is when it gets serious.
The final six.

MARGARITA:
Top six!

Yes!

How you guys feeling?

Nervous. Thankful.

Ayana?

I am super happy

that I'm still here,
but I'm cautious.

[laughing]

HEIDI:
There's some advice

for your next challenge:
proceed...

-with caution.
-MICHAEL: I'm really scared

that we'll be doing
something dangerous.

It's going to be a wild ride.

-Oh, my God.
-So good luck,

and I'll see you
back here on the runway.

Bye, everybody.

Careful.

♪ ♪

-Oh, my God, cars.
-Oh, cars!

It’s a Lexus challenge.

MARGARITA: There's three
beautiful Lexus SUVs.

Yes!
This is the Lexus challenge!

Uh-oh.

Good morning, designers.

-DESIGNERS: Good morning.
-Please join me

in giving a very special welcome
to Brian Bolain.

Brian is the general manager

for product and consumer
marketing at Lexus.

-Hey! -Hi!
-TIM: Welcome, Brian.

BRIAN: Thank you, Tim.
You know, at Lexus,

we have a long history
of being committed to safety.

And to give our drivers
the ultimate peace of mind,

most new Lexus vehicles
feature a suite

of standard
advanced safety items

that we like to call
"Lexus Safety System Plus."

Now, these are our new


and they hold the goods
for your next challenge.

Wow. Okay.

So, designers,
Lexus focuses on safety,

but as you know, in fashion--

and especially
on Project Runway--

we're not about playing it safe.

That's right.

And in that spirit, this will be

an unconventional-materials
challenge.

Oh, Lord, I'm about to pass out.

[laughter]

So, designers,
packed inside these vehicles,

you will find
a wide array of materials

that have been invented
and created with safety in mind.

Oh, my gosh!

-[laughing]
-[sighing]

Okay, I'm down.

For this challenge,
we want you to think

outside of your safety zone

and deliver looks that do not
conform to the rules.

So, since this is

an unconventional-materials
challenge,

we will not be going to Mood.

-All right. -Okay.
-And you will have one day

for this challenge, all right?

[nervous squeal]

So, designers, you're going
to have three minutes

to gather all the unconventional
materials that you can.

Is everybody ready?

-Yeah.
-All right?

-Go.
-[giggling]

AYANA: I know I want
to make a modest look,

which means I'm gonna need more
materials than everyone else.

This is so hard.

I'm not gonna pull an Ayana
and grab everything,

but I'm gonna grab the things
that I think

I can make things out of,
which is very little.

[grunting nervously]

-[chuckling]
-Oh, no!

MARGARITA: I don't want it
to be super obvious, like:

"Construction zone [bleep]."

So I see these kneepads,
and I grab four,

and then I find this,
like, giant harness.

And then, of course, I grab all
these sparkly reflector things,

because who doesn't love
glitter?

KENYA:
I have a rubber boat.

I hate these materials
more than I hate

the last unconventional
challenge.

[laughs]


Go, go, go, go, go.

Just pull, Kenya.

I'm not built for this.

TIM:
Time is up.

All right, everyone?

[grunting, panting]

Back to the workroom.

-KENYA: Caution. [laughs]
-[Tim laughs]

♪ ♪

Walking on in. Oh, Lordy.

Let me see who my model is.

-KENTARO: What did you get?
-Jazzmine.

-I got Meisha again!
-I have Sanita again.

-I have Michael.
-[laughing]

-Hi, Tim.
-Hi. -Hi, Tim.

All right, we're back,
and you have your materials.

Your real goal in this challenge

is to transform these materials

and have them not look
like what they are.

You have one day
for this challenge,

and you have until


[groans] Okay.

With the last challenge,

you raised the bar
for the judges.

You have to keep raising it.

Work hard, hard, hard, hard.

Just so much in here.
[blows whistle]

[grunts]

MARGARITA:
My strategy is

to do a little inventory

and see what
I gravitate towards.

KENYA:
Ayana, are you letting out any

-aggression, anger, um...
-I'm done with this!

[laughter]

I know off the bat
that I want to create volume.

I want to make a ball gown.

I've crushed up
these reflectors

to make a mosaic pattern
on the front,

and then I'm going to sculpt

these really strong
shoulder pads.

BRANDON: I'm just thinking,
"What in the hell

can I make out of this?"

These kind of materials,
I don't know.

I just don't know.

Hey, brother. Can we have
a little consultation

-when you get a sec?
-Yeah.

BRANDON:
I've never been

challenged like this ever.

I can't just have a black skirt.

Maybe you can cut this one
a bit. I don't know.

MARGARITA:
I feel like this competition

is all about, like,

evolving, growing
and improving, and, like,

I feel like I'm challenging
myself every single week

to do something out of the box,

but with Brandon, does he have
something else to show?

I don't know.
Is he a one-trick pony?

MICHAEL:
I'm working very fluidly

with the bungees at this point,

seeing how I can manipulate them

to make them interesting.

I want to do something

bondage-inspired
and sexualized,

but in a very,
very sophisticated way.

AYANA:
Michael wants to create

this fetish-inspired look.

The judges don't
like things that are

too scandalous
or are too, like, trashy.

It's risky, but we're here
to take risks, so...

go for it, Michael.

KENTARO: For this
unconventional challenge,

I'm using the fire hose, and it
happens to have a lot of fabric

wrapped around it,
so I'm, like, lucky, so, like,

I'm going to make a crop top.

Then I'm going to do
a pleated skirt.

The vibe in the workroom
is very tense.

No one wants to share.

Everyone's looking

at everyone else's design.

-What were you doing with this?
-Just breaking them.

And I'm like, okay,
so this is what the competition

-is starting to feel like.
-You got any extra belts?

[chuckling]:
I got any extra belts?

No, I-I only have two left.
I was just seeing

if I wanted to do anything.
I probably won't, to be honest.

KENYA: Right now,
I'm totally freaking out.

The judges, they don't care

what we're using;
they just want

to see fashion hit the runway.

Heidi doesn't take any excuses.

My heart is racing.

HEIDI:
Coming up on Project Runway...

I think this has the potential
for being incredibly chic.

Is it just going to look
very messy?

It's a tough one, Tim.

It is so over the top.

That was not part
of the challenge.

-HEIDI: No.
-What is that?

-[chuckling]
-This is hot.

♪ ♪

You think that,
even in unconventional,

they would pull the
"that's too simple" card.

Depends on what everyone in
the rest of the room is doing.

AYANA:
This week is an

unconventional-materials
challenge from Lexus.

We have to make our look

out of safety materials.

I want you to look at this
and be like,

"That's fashion," not,

"That is some belt buckles

-and some rubber boat."
-Exactly.

I'm making a dress
out of seat belts,

and it's all black.

And everyone else
has all this color.

I'm feeling
like a nervous wreck.

I just need to, like,
calm down and get out

of my own way.

-Hi.
-Hi, Tim. -Hi, Tim!

What? [laughs]

This room looks like
an expl*si*n happened.

-KENYA: It did.
-TIM: It did, didn't it?

How are you all?

-Okay.
-Well, I'm here to check in

with you, and I'm eager
to hear what you're doing

-and see what you're doing.
-KENYA: Okay.

-MARGARITA: Yes.
-Great. Wow.

-What's that? -This...
I don't know what this is.

-It looks like some sort of...
-Some sort of seat belt?

I, like, played around
with this.

And right now, I mean,
I'm trying

to figure it out for you,
but this sits right here.

At first, I was dubious, but now
that you've done it, I see it.

-Is it too simple? 'Cause my
fear is that it's... -No.

-You know, it's like...
-No, no, no, no, no, no.

It's very innovative.

It is not even remotely
too simple.

I'm just concerned, like,
I'm not gonna do enough.

I think you're at a juncture
where you're

-thinking too much.
-Yeah.

-Just do it.
-Okay.

So the top is gonna be
really sleek and fitted.

And one of the things that I was
looking at was the reflectors.

-Trying to cover the whole thing
with these. -Good.

And then the bottom of it,
I wanted the bottom to be

as big as I could
possibly get it.

-Out of what?
-That.

-Oh. -The concept
that I was going with

is that I wanted the bottom
to look like fire.

I think this has the potential
for being incredibly chic.

I decided to take

all of the buckles

and do a woven pattern
and create my textile.

Why aren't you weaving it?
Why isn't it

going in and out, in and out?

Well, it'll be--
I won't have enough to do it

-all the way through.
-Why don't you just

put them into either vertical
or horizontal strips?

Because you'll have
more material to work with.

-Yeah. -And is it all
going to be black?

-Yeah.
-What do I keep saying to you?

-Turn up the volume?
-You need to turn up the volume.

I’m kind of just working
with the bungee cord.

-Okay. -And letting it
kind of shape itself.

-This goes over this?
-Yeah.

MICHAEL:
I know that I have enough

to show him where

I want to go with this design,

but I'm really scared that Tim
might think

it's not pushing design
far enough.

-Well, can I be honest with you?
-Yeah.

-Please. -They look like
two very different looks.

-Yeah.
-I just don't see them together.

I mean, I would commit to one
or the other and move forward.

I found this fire hose,

and I kind of just,
like, took it

because I like the color.

And I didn't know
this expands into,

like, actual fabric,
so I feel kind of lucky.

-However...
-However?

...it is actual fabric.

-Yeah.
-So, the point is

to transform whatever it is.

And this is fabric
that you’re using as fabric.

-Mm-hmm.
-That concerns me tremendously.

I'm just very concerned

-that the judges will say,
"It’s fabric." -I agree.

Out of the little
tube boat thing,

made a circle skirt.

And then the color story is:
silver,

black, with, like,
pops of yellow.

-Talk to me about the top.
-I'm just gonna do, like,

kind of a basic T-shirt,
probably crop top.

What-what is...

-What is this? Are you using it?
-Yeah.

This is the emergency blanket
or whatever.

How do you feel about this?

Is it just going to look
very messy

compared to this
very tailored skirt?

Yeah.

Quite frankly,
standing with you now,

I'm worried about what
you're actually working on.

I have a responsibility to say
to you, "I’m-I’m losing you."

♪ ♪

It's a tough one, Tim.

I don't know. I don't know.

HEIDI:
Coming up on Project Runway...

I think I have to do
something with this top.

MARGARITA: I have to add
something more to this,

'cause it's too simple.

CHRISTINA: Grab some pizza
and some popcorn,

'cause you're gonna see
a naked girl

-on Project Runway.
-[Ayana squeals]

One of the things that I think
is a signature of yours

is that you play so inventively
with silhouette,

-and I don't see that
happening here. -Right.

This one is really just...
it's-it's challenging.

The materials--
it was... I don't know.

I don't like leaving you
like this.

-I will muscle through.
-All right, keep... just keep

developing this, and think
of an alternative to this.

-All right, Tim.
-Okay. Carry on.

-All right, you as well.
Thank you. -Thank you.

Designers, I have seldom
had the privilege of working

with such incredibly
talented designers.

And I do not say that
casually or lightly.

And it makes me sick
to think that one of you

could potentially leave,
but one of you will.

So feel that you need
to push this, because you do.

Your models will be in
in 90 minutes.

You have until 11:00 tonight,

and I will see you
in the morning.

-Thank you, Tim.
-Go, go, go. Work, work, work.

-All right. Thanks, Tim.
-Thank you.

♪ ♪

What else are you using?

-Are you still using this?
-MICHAEL: No.

-Why? -Tim does have
a negative reaction to...

the bralette that I created.

I think it's fly as hell.

I'll see what it
looks like on her.

It's kind of all

I have to put and cover
her boobs.

I think, don't scrap this.

Try it on her.

MICHAEL:
So I'm thinking that I might

just stick with it and not
have to create an alternative.

Ayana about to make a damn
Christmas tree over there.

They're gonna be
looking at us like,

"Oh, so y'all
didn't have enough time?

"Oh, but Ayana did all this,

but y'all ain't have
enough time?"

I'm just saying,
don't be trying to show us up.

-That's definitely my goal.
-[laughs]

It ain't... All right, I won't
take it personal, though.

-[gasps]
-Yes!

Yay!

Hello, hello.

[laughing]:
Oh, my God.

KENTARO:
I am stressed out because Tim

wasn't happy with it, I guess,

but at the end, there's nothing
I can come up with,

so I had to go back

to my original plan.

I feel awful, but...

what am I supposed to do?

I think I have to do something

-with this top.
-Mm-hmm.

Top, maybe I should
make a tank top.

LIRIS: Kentaro's mind is kind of
spaced out right now,

as far as what he's going
to make me.

I'm hoping that he goes back
to the drawing board

and comes back
with something fabulous.

This is why I love using you.

[both laughing]

[Ayana squeals, Meisha laughs]

I love my look.
I think it's-it's stunning.

See, this-this uses
my shoulders very well.

-Awesome.
-It fits wonderfully.

I'm really, really excited.

I think it's gonna look
amazing.

AYANA: This is giving me life
right now, so..

I'm very happy.

-I'm gonna try so hard not to
poke you or stab you. -Okay.

Wow. That's sexy.

Sanita, stop flirting with me.

-Your booty.
-[laughter]

CHRISTINA:
I've been dying to work

with Michael as a designer,
so I'm really

excited that finally I get to
wear something that he created,

but I'm wearing
the bungee outfit, and it

has nothing underneath.
I'm telling you,

I'm naked, guys.
I'm, like, naked.

So grab some pizza
and some popcorn,

'cause you're gonna see
a naked girl on Project Runway.

-All right, babe.
-See you in the morning.

-See you tomorrow. -See you.
-Make it work.

-Bye, gorgeous ladies.
-Bye. Good luck, you guys!

♪ ♪

BRANDON:
This could be it.

This foil top,

it looks cool, but it's...
it's ripping,

and I need to make a new top.

I have these life jackets

that I can sew them together

and manipulate it

to use it as fabric.

♪ ♪

MICHAEL:
Oh, my God.

-This is awful.
-Hmm? Huh?

-It looks like a
stripper outfit. -Let me see.

Like, this is definitely going.

-MARGARITA: The bag?
-I'm not... I don't love

-the plastic part...
-MICHAEL: It's disgusting.

-Take it off.
-...but the top part is nice.

Disgusting.

By the end of the day,
I'm definitely

seeing that I have a lot
of issues with my look,

in particular with the dress
underneath.

I don't know how to make it
interesting enough or bring it

to the next level.

[sighs]
I hate it. I hate it.

All right, guys,
it's time to go.

MARGARITA:
No...

MICHAEL:
I'm still really scared

that I'm not doing enough to
impress the judges this week.

HEIDI:
Coming up on Project Runway...

♪ ♪

MICHAEL:
My hands are...

drenched in sweat.

My entire dress will collapse.

-This is not right.
-[gasps]

Uh-oh.
Nope, we gotta take this off.

KENYA:
The whole zipper just came off.

-[gasps] No!
-Oh, my God.

♪ ♪

MARGARITA [sighing]:
Okay. Oh, God.

MICHAEL:
I'm really rushing

to incorporate a new element
in my design.

I do have a bit of netting
that I can use, but...

sewing this net
is actually really hard.

-[sighs]
-KENTARO: Aah!

This is so freaking ill-fitting.

I feel so screwed right now.

I am so nervous

that I will not be able
to get this done.

It's clearly unfinished.

Seat belts are fraying.

It-it's not looking good.

[laughs]

Good morning, everyone.

-Hey, Tim.
-[laughing]

If you're in the Brother
Sewing and Embroidery Studio,

-please come in.
-You got it.

Thank you. Just for a minute.
All right, everyone.

You will have an hour
to send your models

to the Avon Beauty Lab
and to our hair studio.

Use the JCPenney
accessory wall carefully.

-KENYA: Got it. -And your models
are coming in momentarily.

-I will see you soon.
Thank you. -Okay, all right.

-Thank you, Tim.
-Thank you, Tim.

-Hello.
-Hi!

-How are you?
-Hi.

AYANA:
It's a lot.

All right, but it fits.

[singsongy]:
Thank Jesus!

My look...

has so much inventiveness.

The color story's
really strong.

I think it's graphic.
It's actually wearable.

I might have a win here, people.

Let's pray.

JAZZMINE:
I love Brandon's look.

Wearing it down the runway,
I'm excited.

I just hope
that you can't see my butt.

[chuckles] Uh, because it is
a little short in the back.

Hopefully we don't have, like,
a little flash of the booty.

As soon as you get onto
the runway, you're gonna grab it

and throw it,
and then you'll walk down.

MICHAEL:
Looking at Ayana's look,

it's just so beyond
over the top

in, like,
the worst way possible.

She might be

in trouble with this one.

AYANA:
Awesome, awesome.

♪ ♪

-Okay.
-How are you? -Good.

So I want to do
a shiny black lip.

HECTOR: So, we're going
to grab this eye shadow

from the 8-in-1 Palette,

mix it with this,
so that way we get it,

like, really dark.
And still shiny.

-[camera shutter clicks]
-MICHAEL: Perfect. Wow.

And I want to have, like,
white eyeliner.

HECTOR:


KENTARO:
And a blue mascara.

-[camera shutter clicks]
-Perfect.

MARGARITA: There's so much
going on with the look.

HECTOR: Let's keep it
really, really simple.

We do a little bit of the brows
and really bright lips.

-Stunning. Awesome.
-[camera shutter clicks]

MICHAEL: Why did I decide
to do the stupidest,

hardest thing to put on?

MARGARITA: Michael's
is like bondage couture.

Like, she is just like...
[hums a tune]

It's probably too sexy
for Nina.

-I'm gonna trim it so it's not
gonna be that long. -Mm-hmm.

CHRISTINA:
Now I have an outfit.

With no clothes,

it was "sexy,"
but with all of this,

everything fits,
it-it goes together,

and I'm not naked,
so I'm pretty happy about that.

AYANA: My first thought is,
"Oh, my God,

she looks like a doll.
Liris looks like a doll."

I'm not sure what the judges
will think.

KENTARO:
This cut is cute.

Hmm.

I like the skirt,

but the top--
he's just clueless.

I look like Pocahontas
is about to go play football.

Designers, in ten minutes,
you and your models and I

are going down to the runway.
Ten minutes. Thank you.

Could I have you,
like, hold it again?

My hands are...

like, drenched in sweat,

and it's pretty impossible

to zip the dress up.

And if she walks out
with a half-open zipper,

my entire dress will collapse.

This is not right.

Uh-oh.

My sleeve falls off.

What is this?
Nope, we gotta take this off.

I was running so late
that I just kind of glued

the bottom part of the sleeve,
and I knew it was a risk.

I literally put these on seconds
before the end of the night.

I am very concerned

that the sleeve might fall off

when she goes
to rip the caution tape off,

but I'm not willing
to give up that effect.

We literally have like
five minutes at this point.

[Kenya gasps, whimpers]

-The whole zipper just came off.
-[gasps] No!

My zipper has just broken.

I'm devastated.

I don't know what to do.

-All right, everyone.
-Is that Tim? That's Tim?

Designers and models,
we're headed down to the runway.

MARGARITA:
I'm scared for Kenya.

The whole back of her garment
zipperless?

Any mistake could send you home.

KENYA: This is the top six,
and it's just

a simple black dress
with a broken zipper?

I could easily be
on the bottom.

My heart is racing.

HEIDI:
Coming up on Project Runway...

-I adore this.
-She could've just been

wearing that and a trash bag,
and I would've loved it.

NINA:
It's just very cool.

I see a lack of vision.

Yeah, I'm not a fan.

-Hello.
-Hello. -Hi.

Welcome to the runway.
As you know,

in fashion, one day you're in,

and the next day you're out.

There are six of you here,
and after tonight,

there will be five.

Well, this is when it gets
all very, very real.

-[laughs]
-Every single stitch counts.

There's no more room for error.

This was the unconventional-
materials challenge,

and I love the unconventional-
materials challenge.

I think that they
really push you

to really think
outside of the box.

You used safety materials
to create fashion

suitable for this very runway.

All right,
let's say hello to our judges.

First, we have creative director
of Brooks Brothers Women

-and fashion designer,
Zac Posen. -Hi, designers.

Creative director
for Marie Claire magazine,

-Nina Garcia.
-Hello, designers.

And star of the hit series,
Mr. Robot, Carly Chaiken.

-Welcome. -Thank you.
-Hi, Carly.

Also, we have Tim Gunn here
for the runway show. Hi, Tim.

-KENYA: Hi, Tim. -And, as
you know, he is your mentor

and will not be judging
your looks.

He will have the Tim Gunn save.

If, at some point
during the competition,

he disagrees with the judges,
then he can bring

that eliminated designer back
to the competition.

-Tim, I think this
is challenge ten. -It is.

And you have not used your save.

-We're getting closer and
closer, though, Heidi. -Okay.

It is a little bit
of a nail-biter, isn't it?

-Oh, yeah. -We also have
an anonymous runway show.

That means we, the judges,
do not know which designer

created which look.

All right, let's start the show.

MAN:
Here we go.

♪ ♪

BRANDON: It's moving nice.
I think it has, like,

a lot of flow
even though the materials

are so rough and rugged.

And I feel a thousand times
more confident

that the skirt's not too mini,

so I'm feeling great about it.

♪ ♪

KENTARO: I'm not happy
with what I made,

but I feel like
it's kind of good enough.

It doesn't look that bad.

♪ ♪

Okay, okay.

MICHAEL: I'm pretty happy
with what I created.

As simple as it is,
and as minimal as it may seem,

I know that I have a very
strong concept in my head,

and I'm very pleased
with what I produced today.

♪ ♪

AYANA:
Meisha looks amazing.

Everything
that I wanted to bring

is right in front of me.
The mosaic is sparkling.

I freaking love it.

♪ ♪

KENYA:
She looks great.

My dress came out pretty much
the way I expected.

It's a little bit weird because
I made the hips kind of wide.

-The texture is amazing.
-But I like it.

I really think that it looks
really, really good.

MARGARITA: My look has
so much inventiveness to it.

KENYA: I want my
imagination to allow me

to go places like this.

MARGARITA: That harness
placement is fire.

I'm so happy I did this look.

It's really cool
and very colorful.

I'm just so excited.

I want to wear it.
It's so badass.

HEIDI: We have just learned
which designer

created which look.

I have to say, all of you did

a really amazing job today.

There's nothing really there

that we don't like.

-NINA: Mmm... Ah...
-ZAC: Mmm...

-HEIDI: Well...
-[judges laughing]

But not, like, hate-hate,
like we sometimes do.

No.

One of you
will be named the winner,

and one of you will be out.

Brandon, tell us about your look
and the materials that you used.

The base of the skirt and then
the half portion of the top

is made from a life raft.

And this here was a hose
that I cut to a geo pattern.

Just kind of playing
with shape here

and using the hose again
to form shape.

-And how was this challenge for
you? -At first, I didn't know

what to do, and I was, like,
trying to, like, sculpt.

HEIDI:
Was it really hard to sew this?

Yeah, it-it was tough.
I was getting used to it,

and I worked it, and...
and then yeah.

ZAC:
I adore this.

Just spectacular work.

Love you working
with alternative materials.

I think it forces you
to play with color.

-Definitely.
-It forces you to play

with unusual textures.

-Definitely. -Beautiful.
Can she turn to the side?

-A little short on the back.
-Yeah.

However, I just think this was,
like, the top of the top.

Thank you.

When she walked down the runway,
it was just moving beautifully.

You almost created a print,

but it feels very street.

I really loved it.

The wrist thing
was the first thing

-that I was like,
"What is that?" -[laughter]

-It looked like a phone charger.
-ZAC: The bobbles.

But I love what you did
with all the lines

and just the placement
of all the colors

and the placement
of the orange patches.

I thought it was all great.
I want that top.

Thank you.

HEIDI:
Michael, tell us about your look

and the materials that you used.

MICHAEL:
The majority was bungee cord.

I did the interior bralette
out of the harness strapping.

The skirt was all
out of ACE bandages.

But my basic inspiration
was kind of beautifying bondage.

Yeah, Michael, unfortunately,

this is not one
of my favorite looks.

It lacks drama.

This was the unconventional-
material challenge.

This is about freedom.
This is about creativity.

And this feels
like a bandage dress.

She looks like a backup dancer
for a music video.

To be very blunt, I think she...
it's very hooker-ish.

Looks a little, like,
tacky and cheap.

Yeah, I'm not a fan.

HEIDI:
I do kind of think

she looks hot,
but when you do compare

your look to everyone else's,

it looks like you
didn't work as hard.

Kenya.

I had two things.
I had a plastic boat,

and I had a ton of seat belts.

I took the seat belts,
and I came up

with this idea
to make a dress of it.

And I used the boat as structure

to create the shape
of the dress.

And then I added
a little bit of paint

to give it a little bit of more
texture, kind of like a textile.

I think this is very good.

It has a lot of great detail.

The little hat
that you made for her.

I love that the seat belt
is actually the belt.

Just simple-- boom, there it is.

I don't know, in the back,

-you couldn't really close it?
-The zipper broke.

Soon as I put it on her,
it... it broke.

HEIDI: But I think you created
a really cool dress

made out of seat belts.

Thank you.

This is an example
of how you can do drama

and you don't need to put
everything and the kitchen sink.

It is just a black dress,

but the drama comes
in the silhouette,

in the shine
and this stiffness to the dress.

It's part of that
exaggerated silhouette.

So it worked.

Thank you, Kenya.

HEIDI:
Ayana.

My look was intended to pull out
all the stops and take risks.

The materials that I used
are a lifeguard float

to make the shoulder pads,

reflectors to get
broken-glass mosaic effect.

This net is what road workers
use to kind of separate areas.

I stitched together
some danger tape to make

her hijab out of.

This look is so fantastic.

It is so over the top.
I just love it.

I love the hard hat that really
gives it the extra oomph.

It's sleek. It's modern.

-It's chic.
-Thank you.

This is hot.

This was bold. This was big.

I like you using
alternative materials.

It has a real tactile quality.

I personally felt that the top
is a teeny bit outdated.

Give me a little bit
of, like, an '80s thing.

It's a little cliché, the top,
but in general,

I think this is superb work.

My favorite part, actually,
is the pop of blue at the top.

Like, as subtle as it is,
just tied

all the colors together, too.

Really, really cool.

HEIDI: Margarita,
tell us about your look.

I was very inspired
by the Lexus cars.

They're super high-gloss
and chic,

so I kind of wanted to create

a c*ck dress
that had that vibe.

First, I used the caution tape,
and I wove it.

I attached these reflectors,
and then on top,

these are kneepads.

These pieces are hard hats

that I sawed off,
and this piece

was, like, a safety harness
that was really big.

I had fun. It was really fun

to experiment with a lot
of different things.

I really like this, Margarita.

I'm getting a superhero vibe
from her.

It was innovative.

I love the use
of the reflectors.

The straps.
It's just very cool.

-Thank you.
-CARLY: I kind of almost wish

you brought a tiny...
like a... more of that blue

and a hint of that into
the skirt maybe or something.

But the shoulders on that,
with the hard hat,

she could've just been
wearing that and a trash bag,

and I would've loved it.

-[chuckling]
-HEIDI: I loved it, too.

I think this girl
is very modern.

I feel like you could mix her
into some of the shows

that you see in Paris right now
and she would fit right in.

I don't still have an idea
of what your style is.

You know, we saw...

You'll have to see a collection.

Well, I know, but I don't know

what you have to say
about fashion.

It's not a tight aesthetic yet
for me.

HEIDI:
Kentaro.

I used a fire hose.

Wanted to make layers of fringe.

These yellow parts are made
out of the yellow cone.

This is what I created.

This is not one
of my favorite outfits.

I see a lack of vision.

I just don't know when you
decided to take the direction

that you wanted this to look
like a Native American costume.

-That was not part of
the challenge. -HEIDI: No.

She almost looks like a doll.

Like, it's all
a little bit too stiff.

If her hair was in
a sleeked-back pony

and she had simpler shoes on,

it would have made all
the difference in the world.

It's not, to me, very fashiony.

And it just feels...

a little basic.

Liris, how do you feel in it?

There's a piece
that, like, cuts my arm here.

Yeah, it's like fiberglass,
right?

-Yeah. It's very stiff.
-Yeah, it's fiberglass.

I've never seen you
this uncomfortable.

Fibers in her armpit
making me itchy.

HEIDI:
Thank you, Kentaro.

Thank you.

Okay, we've heard
what you had to say.

We're going to take
a closer look

at your designs,
have a little chat,

and then I'll call you back
onto the runway.

Now you can leave the runway.
Thank you.

-Thank you.
-♪ ♪

HEIDI: The winner
of Project Runway will receive

the opportunity to collaborate
with JCPenney

on a limited edition
capsule collection

as part
of the Project Runway line sold

at select JCPenney stores
and online at JCP.com;

a selection of Brother sewing
and embroidery machines,

with a retail value of $40,000;

makeup and beauty products
for a year, courtesy of Avon;

the new 2018 Lexus NX,
coming this fall

with advanced innovation
and safety system standard;

from the Pilot FriXion
Erasable Pen,

the official pen
of Project Runway,

a lifetime supply of pens;

an all-expense-paid luxury trip
to Japan,

including a five-star stay
near Japan's fashion center;

$100,000 to launch their line;

and the winning designer
and model will receive

a fashion spread
in Marie Claire magazine.

Here we come, and it's not easy
with the steps.

No.

Well, shall Meisha
come out first

wearing Ayana?

-Here she comes.
-She can't hear.

[laughter]

-ZAC: Wow, wow, wow.
-She can't hear.

-Just incredible.
-I need to touch this.

NINA:
This is just insane.

-And what is this?
-TIM: A raft.

-Like, an inflatable raft.
-A boat?

-Yeah.
-And look how she sewed that.

This is unbelievable.

And I love
the textile underneath.

It's the combination
what makes it special.

-Yeah. -She used so many
different materials.

Look at that--
she painted that inside.

-Yeah. -It's really...
-Extraordinary.

♪ ♪

TIM:
Janine wearing Margarita.

-CARLY: It looks better
close up. -ZAC: Yeah.

Yeah, this is phenomenal.

Oh, this was painted.

She actually used the shavings
from the helmet.

-Ah. -Right.
-To create the texture.

Very nice.

♪ ♪

TIM:
And Jazzmine is wearing Brandon.

Can you take that top off
so I can put it on?

-I'm just kidding.
-[laughter]

-Cool. -I mean, he really
worked with the material.

It's very cool, like,
where he placed everything.

Where he placed the stripes,
where he placed the orange.

Created a border here.

This is such a feminine take
for him.

I have to say, as a designer,

Brandon is very,
very thoughtful.

-ZAC: Yeah.
-NINA: You can tell, Tim.

Very thoughtful.

I want to see a runway show
from Brandon.

♪ ♪

TIM:
Sanita is wearing Kenya.

CARLY: Ooh, I love
how she painted this.

-That's great.
-It's nice that she did that.

It gives it more dimension.

NINA:
This was so thoughtful

where she placed the hardware.

♪ ♪

And we have Christina
wearing Michael.

The hooker has arrived.

-[laughter]
-She said it.

-Streetwalker.
-This is the second time

-I've been called hooker.
-It's not personal.

CARLY: I will say, the lips,
that blue there...

You really like. Let me guess.

I don't know.
It looks uncomfortable.

See, I'm not hating it.

-I am. I hate it.
-NINA: I do hate it.

♪ ♪

TIM: Shall we have Liris
come forward?

-ZAC: Yeah.
-HEIDI: Yes.

NINA:
I don't really like this.

I didn't come here
to see a costume.

From the hair to the fringe
to the Navajo detail here.

I just wish he didn't even
put these on it.

It's so, like,
"Oh, let's cut something up

-and put it on for the color."
-I know.

♪ ♪

Okay, so we made our decision?

Let's bring them back out.

♪ ♪

HEIDI: One of you
will be named the winner,

and one of you will be out.

Ayana.

Congratulations. You are
the winner of this challenge.

-[laughs]
-[applause]

AYANA:
Thank you.

[squeals, laughs]

HEIDI:
You can leave the runway.

Thank you so much.

MICHAEL:
Congrats.

[squeals, laughs]

I'm so excited to win again.

I really needed two wins
under my belt.

I feel like

I definitely belong here.

And I cannot wait
to continue to wow the judges.

[chuckles]

Just me celebrating me.

[sighs]

Margarita.

Brandon. Kenya.

You're all in.
You can leave the runway.

Thank you.

♪ ♪

Michael, Kentaro,

one of you will be out.

Michael, you said it yourself.

You didn't do enough
for this challenge.

Your dress lacked imagination.

And you had
a really great model,

but she even ended up
looking cheap.

Kentaro.

And you, you gave us
costume today.

It was the
matchy-matchy styling

that really took
the whole look down.

It was uninspired.

And, at this point,

we really expect more from you.

Michael...

I'm sorry. You're out.

Thank you.

I honestly really
appreciate everything--

all the really honest feedback--
and it's something

that I will definitely
not take for granted.

And I appreciate all of the time
that I've had here.

HEIDI:
Kentaro, that means you're in.

You can leave the runway.

I'm sorry, Michael.

-Auf Wiedersehen.
-Thank you.

Mwah. All the best to you.

Thank you guys so much.

I'm disappointed

to be leaving the competition,

but the fact that I made it
really far

and I made amazing connections
with the rest of the designers,

I'm just very honored
to have been

in the same platform
as all of them.

MICHAEL:
It's...

[Margarita muttering
indistinctly]

The only thing that sucks
is that I'm leaving you guys.

To come here and everyone have,
like, a like passion,

it meant a lot.

MARGARITA:
I just think you're such

a great, great collaborator,

and I'm gonna miss you.

Sorry.

You know, this is only going
to get more emotional,

but I want to say this
before you leave:

You're going home on a high.

I mean, you have two wins
behind you.

-So you should feel great.
-Absolutely.

-But we will miss you.
-BRANDON: We will.

-Bye, homeys.
-Michael.

TIM: So I have to send you
to the workroom

to clean up your space,
regrettably.

BRANDON: You're gonna
be awesome, brother.

Take care.

We're gonna miss you.

-It meant so much.
-Great designer.

-Thank you.
-And we will hear more from you.

Thank you so much.

-Thank you, Michael.
-Bye. Have fun.

BRANDON:
Good-bye, Michael.

It's like losing
a family member.

MICHAEL: The experience
on Project Runway

was honestly
the greatest experience

I could have had
as a creative person.

I am more than happy to
continue to create and continue

to be surrounded
by creative people.

That's honestly
all I've ever wanted.

HEIDI:
Next time on Project Runway...

-[bell rings]
-[laughter, whooping]

You are to create a high-fashion

look inspired by warrior women.

I don't know
what I'm doing right now.

Uh-oh.
It’s not fitting.

I don’t know
what’s going to happen.

[bleep] Any tiny little mistake
can send you home.

AYANA:
Brandon, I'm gonna give you

a run for your money.
[chuckles]

[squeals]

Ayana, you sneaky little thing.

-Wow. -You delivered
on the power of fashion.

It's just beautifully tailored.

What is that?
I had great hopes for you.

HEIDI: Visit myLifetime.com
to learn more

about the fashion you've seen
on tonight's show.